pub struct NotificationsSettings {
session: WeakRef<Session>,
api: RefCell<Option<NotificationSettings>>,
account_enabled: Cell<bool>,
session_enabled: Cell<bool>,
global_setting: Cell<NotificationsGlobalSetting>,
keywords_list: StringList,
per_room_settings: RefCell<HashMap<OwnedRoomId, NotificationsRoomSetting>>,
abort_handle: RefCell<Option<AbortHandle>>,
}Fields
session: WeakRef<Session>The parent Session.
api: RefCell<Option<NotificationSettings>>The SDK notification settings API.
account_enabled: Cell<bool>Whether notifications are enabled for this Matrix account.
session_enabled: Cell<bool>Whether notifications are enabled for this session.
global_setting: Cell<NotificationsGlobalSetting>The global setting about which messages trigger notifications.
keywords_list: StringListThe list of keywords that trigger notifications.
per_room_settings: RefCell<HashMap<OwnedRoomId, NotificationsRoomSetting>>The map of room ID to per-room notification setting.
Any room not in this map uses the global setting.
abort_handle: RefCell<Option<AbortHandle>>Implementations
Sourceimpl NotificationsSettings
impl NotificationsSettings
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl NotificationsSettings
impl NotificationsSettings
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the parent Session.
Sourcefn set_session_enabled(&self, enabled: bool)
fn set_session_enabled(&self, enabled: bool)
Set whether notifications are enabled for this session.
Sourcepub(super) fn api(&self) -> Option<MatrixNotificationSettings>
pub(super) fn api(&self) -> Option<MatrixNotificationSettings>
The SDK notification settings API.
Sourcepub(super) fn set_account_enabled(&self, enabled: bool)
pub(super) fn set_account_enabled(&self, enabled: bool)
Set whether notifications are enabled for this session.
Sourcepub(super) fn set_global_setting(&self, setting: NotificationsGlobalSetting)
pub(super) fn set_global_setting(&self, setting: NotificationsGlobalSetting)
Set the global setting about which messages trigger notifications.
Sourcepub(super) async fn update_keywords_list(&self)
pub(super) async fn update_keywords_list(&self)
Update the local list of keywords with the remote one.
Sourcepub(super) async fn update_per_room_settings(&self)
pub(super) async fn update_per_room_settings(&self)
Update the local list of per-room settings with the remote one.